@@ -3,7 +3,7 @@ BEGIN {
   $Dist::Zilla::PluginBundle::FLORA::AUTHORITY = 'cpan:FLORA';
 }
 BEGIN {
-  $Dist::Zilla::PluginBundle::FLORA::VERSION = '0.10';
+  $Dist::Zilla::PluginBundle::FLORA::VERSION = '0.11';
 }
 # ABSTRACT: Build your distributions like FLORA does
 
@@ -52,6 +52,12 @@ has disable_pod_coverage_tests => (
     default => 0,
 );
 
+has disable_trailing_whitespace_tests => (
+    is      => 'ro',
+    isa     => Bool,
+    default => 0,
+);
+
 has bugtracker_url => (
     isa     => Uri,
     coerce  => 1,
@@ -263,7 +269,6 @@ method configure {
         PkgVersion
         PodSyntaxTests
         NoTabsTests
-        EOLTests
     ));
 
     $self->add_plugins('PodCoverageTests')
@@ -281,7 +286,10 @@ method configure {
         [Authority => {
             authority   => $self->authority,
             do_metadata => 1,
-        }]
+        }],
+        [EOLTests => {
+            trailing_whitespace => !$self->disable_trailing_whitespace_tests,
+        }],
     );
 
 
@@ -301,6 +309,8 @@ __PACKAGE__->meta->make_immutable;
 __END__
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 Dist::Zilla::PluginBundle::FLORA - Build your distributions like FLORA does
@@ -347,7 +357,7 @@ It is roughly equivalent to:
 
 =head1 AUTHOR
 
-  Florian Ragwitz <rafl@debian.org>
+Florian Ragwitz <rafl@debian.org>
 
 =head1 COPYRIGHT AND LICENSE
 
